genkit_shelf library

Classes

FlowWithContextProvider
A wrapper object containing a flow with its associated auth policy.

Functions

shelfHandler(Action action, {ContextProvider? contextProvider}) → Handler
Exposes provided flow or an action as shelf handler.
startFlowServer({required List flows, int port = 3400, Map<String, dynamic>? cors}) Future<HttpServer>
Starts a shelf server with the provided flows and options.

Typedefs

ContextProvider = FutureOr<Map<String, dynamic>> Function(Request request)
Context provider function.